@@ -1101,6 +1101,7 @@ class RemoteHeavyDB(RemoteJIT):
                 target_info.add_library('stdio')
                 target_info.add_library('stdlib')
                 target_info.add_library('heavydb')
+                target_info.add_library('NRT')
             elif target_info.is_gpu:
                 if self.version < (6, 2):
                     # BC note: older heavydb versions do not define
@@ -1374,7 +1375,8 @@ class RemoteHeavyDB(RemoteJIT):
                 compiler = ctools.Compiler.get(std='c')
             if self.debug:
                 print(f'compiler={compiler}')
-
+            if compiler is None:
+                return
             from numba import _min_llvm_version
 
             url = "https://numba.readthedocs.io/en/stable/user/installing.html#version-support-information"  # noqa: E501
